@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package Email::Simple;
 # ABSTRACT: simple parsing of RFC2822 message format and headers
-$Email::Simple::VERSION = '2.204';
+$Email::Simple::VERSION = '2.205';
 use Carp ();
 
 use Email::Simple::Creator;
@@ -161,8 +161,8 @@ sub create {
 
   my $email = $class->new($header);
 
-  $email->header_raw_set(Date => $CREATOR->_date_header)
-    unless defined $email->header_raw('Date');
+  $email->header_set(Date => $CREATOR->_date_header)
+    unless defined $email->header('Date');
 
   $body = (join $CREATOR->_crlf, split /\x0d\x0a|\x0a\x0d|\x0a|\x0d/, $body)
         . $CREATOR->_crlf;
@@ -222,14 +222,6 @@ sub header_obj_set {
 #pod in, you get multiple headers, and order is retained.  If no values are given to
 #pod set, the header will be removed from to the message entirely.
 #pod
-#pod =method header_raw
-#pod
-#pod This is another name (and the preferred one) for C<header>.
-#pod
-#pod =method header_raw_set
-#pod
-#pod This is another name (and the preferred one) for C<header_set>.
-#pod
 #pod =method header_names
 #pod
 #pod     my @header_names = $email->header_names;
@@ -249,20 +241,11 @@ sub header_obj_set {
 #pod Every other value, starting with and including zeroth, is a header name and the
 #pod value following it is the header value.
 #pod
-#pod =method header_raw_pairs
-#pod
-#pod This is another name (and the preferred one) for C<header_pairs>.
-#pod
 #pod =cut
 
 BEGIN {
   no strict 'refs';
-  for my $method (qw(
-    header_raw header
-    header_raw_set header_set
-    header_raw_pairs header_pairs
-    header_names
-  )) {
+  for my $method (qw(header header_set header_names header_pairs)) {
     *$method = sub { (shift)->header_obj->$method(@_) };
   }
   *headers = \&header_names;
@@ -333,7 +316,7 @@ Email::Simple - simple parsing of RFC2822 message format and headers
 
 =head1 VERSION
 
-version 2.204
+version 2.205
 
 =head1 SYNOPSIS
 
@@ -436,14 +419,6 @@ Sets the header to contain the given data. If you pass multiple lines
 in, you get multiple headers, and order is retained.  If no values are given to
 set, the header will be removed from to the message entirely.
 
-=head2 header_raw
-
-This is another name (and the preferred one) for C<header>.
-
-=head2 header_raw_set
-
-This is another name (and the preferred one) for C<header_set>.
-
 =head2 header_names
 
     my @header_names = $email->header_names;
@@ -463,10 +438,6 @@ This method returns a list of pairs describing the contents of the header.
 Every other value, starting with and including zeroth, is a header name and the
 value following it is the header value.
 
-=head2 header_raw_pairs
-
-This is another name (and the preferred one) for C<header_pairs>.
-
 =head2 body
 
 Returns the body text of the mail.
