@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Email::Simple::Header;
 # ABSTRACT: the header of an Email::Simple message
-$Email::Simple::Header::VERSION = '2.204';
+$Email::Simple::Header::VERSION = '2.205';
 use Carp ();
 
 require Email::Simple;
@@ -139,9 +139,9 @@ sub header_names {
     map { $headers->[ $_ * 2 ] } 0 .. int($#$headers / 2);
 }
 
-#pod =method header_raw_pairs
+#pod =method header_pairs
 #pod
-#pod   my @pairs = $header->header_raw_pairs;
+#pod   my @pairs = $header->header_pairs;
 #pod   my $first_name  = $pairs[0];
 #pod   my $first_value = $pairs[1];
 #pod
@@ -149,17 +149,9 @@ sub header_names {
 #pod order that they appear in the header.  (Remember: don't try assigning that to a
 #pod hash.  Some fields may appear more than once!)
 #pod
-#pod =method header_pairs
-#pod
-#pod L<header_pairs> is another name for L<header_raw_pairs>, which was the original
-#pod name for the method and which you'll see most often.  In general, though, it's
-#pod better to be explicit and use L<header_raw_pairs>.  (In Email::MIME,
-#pod L<header_str_pairs> exists for letting the library do the header decoding for
-#pod you.)
-#pod
 #pod =cut
 
-sub header_raw_pairs {
+sub header_pairs {
   my ($self) = @_;
 
   my @pairs = map {; _str_value($_) } @{ $self->{headers} };
@@ -167,30 +159,19 @@ sub header_raw_pairs {
   return @pairs;
 }
 
-sub header_pairs {
-  my ($self) = @_;
-  $self->header_raw_pairs;
-}
-
-#pod =method header_raw
+#pod =method header
 #pod
-#pod   my $first_value = $header->header_raw($field);
-#pod   my @all_values  = $header->header_raw($field);
+#pod   my $first_value = $header->header($field);
+#pod   my @all_values  = $header->header($field);
 #pod
 #pod This method returns the value or values of the given header field.  If the
 #pod named field does not appear in the header, this method returns false.
 #pod
-#pod =method header
-#pod
-#pod This method just calls C<header_raw>.  It's the older name for C<header_raw>,
-#pod but it can be a problem because L<Email::MIME>, a subclass of Email::Simple,
-#pod makes C<header> return the header's decoded value.
-#pod
 #pod =cut
 
 sub _str_value { return ref $_[0] ? $_[0][0] : $_[0] }
 
-sub header_raw {
+sub header {
   my ($self, $field) = @_;
 
   my $headers  = $self->{headers};
@@ -207,27 +188,14 @@ sub header_raw {
   }
 }
 
-sub header {
-  my ($self, $field) = @_;
-  $self->header_raw($field);
-}
-
-#pod =method header_raw_set
+#pod =method header_set
 #pod
-#pod   $header->header_raw_set($field => @values);
+#pod   $header->header_set($field => @values);
 #pod
 #pod This method updates the value of the given header.  Existing headers have their
 #pod values set in place.  Additional headers are added at the end.  If no values
 #pod are given to set, the header will be removed from to the message entirely.
 #pod
-#pod =method header_set
-#pod
-#pod L<header_set> is another name for L<header_raw_set>, which was the original
-#pod name for the method and which you'll see most often.  In general, though, it's
-#pod better to be explicit and use L<header_raw_set>.  (In Email::MIME,
-#pod L<header_str_set> exists for letting the library do the header encoding for
-#pod you.)
-#pod
 #pod =cut
 
 # Header fields are lines composed of a field name, followed by a colon (":"),
@@ -239,7 +207,7 @@ sub header {
 # However, a field body may contain CRLF when used in header "folding" and
 # "unfolding" as described in section 2.2.3.
 
-sub header_raw_set {
+sub header_set {
   my ($self, $field, @data) = @_;
 
   # I hate this block. -- rjbs, 2006-10-06
@@ -275,11 +243,6 @@ sub header_raw_set {
   return wantarray ? @data : $data[0];
 }
 
-sub header_set {
-  my ($self, $field, @data) = @_;
-  $self->header_raw_set($field, @data);
-}
-
 #pod =method crlf
 #pod
 #pod This method returns the newline string used in the header.
@@ -367,7 +330,7 @@ Email::Simple::Header - the header of an Email::Simple message
 
 =head1 VERSION
 
-version 2.204
+version 2.205
 
 =head1 SYNOPSIS
 
@@ -405,9 +368,9 @@ This returns a stringified version of the header.
 This method returns a list of the unique header names found in this header, in
 no particular order.
 
-=head2 header_raw_pairs
+=head2 header_pairs
 
-  my @pairs = $header->header_raw_pairs;
+  my @pairs = $header->header_pairs;
   my $first_name  = $pairs[0];
   my $first_value = $pairs[1];
 
@@ -415,44 +378,22 @@ This method returns a list of all the field/value pairs in the header, in the
 order that they appear in the header.  (Remember: don't try assigning that to a
 hash.  Some fields may appear more than once!)
 
-=head2 header_pairs
+=head2 header
 
-L<header_pairs> is another name for L<header_raw_pairs>, which was the original
-name for the method and which you'll see most often.  In general, though, it's
-better to be explicit and use L<header_raw_pairs>.  (In Email::MIME,
-L<header_str_pairs> exists for letting the library do the header decoding for
-you.)
-
-=head2 header_raw
-
-  my $first_value = $header->header_raw($field);
-  my @all_values  = $header->header_raw($field);
+  my $first_value = $header->header($field);
+  my @all_values  = $header->header($field);
 
 This method returns the value or values of the given header field.  If the
 named field does not appear in the header, this method returns false.
 
-=head2 header
+=head2 header_set
 
-This method just calls C<header_raw>.  It's the older name for C<header_raw>,
-but it can be a problem because L<Email::MIME>, a subclass of Email::Simple,
-makes C<header> return the header's decoded value.
-
-=head2 header_raw_set
-
-  $header->header_raw_set($field => @values);
+  $header->header_set($field => @values);
 
 This method updates the value of the given header.  Existing headers have their
 values set in place.  Additional headers are added at the end.  If no values
 are given to set, the header will be removed from to the message entirely.
 
-=head2 header_set
-
-L<header_set> is another name for L<header_raw_set>, which was the original
-name for the method and which you'll see most often.  In general, though, it's
-better to be explicit and use L<header_raw_set>.  (In Email::MIME,
-L<header_str_set> exists for letting the library do the header encoding for
-you.)
-
 =head2 crlf
 
 This method returns the newline string used in the header.
